PROGRAM print_thermo
!USE kinds, ONLY :: DP

USE phdos_module,  ONLY : phdos_type, read_phdos_data, zero_point_energy, &
                          free_energy, vib_energy, vib_entropy, &
                          specific_heat_cv, integrated_dos
IMPLICIT NONE
INTEGER, PARAMETER :: DP=SELECTED_REAL_KIND(12,100)
CHARACTER(LEN=256) :: file_dos_1

INTEGER :: i, ios
REAL(DP) :: temp1, temp2, e0, deltat, tot_states
REAL(DP), ALLOCATABLE :: temp(:), f_ene(:), ene(:), ent(:), cv(:)
INTEGER :: ntemp, itemp

TYPE(phdos_type) :: phdos_1
!
!  Input sector
!
READ( 5, *, err=200, end=200, iostat=ios ) file_dos_1
200 IF (ios /= 0) STOP 'reading file_dos_1'
CALL read_phdos_data(phdos_1, file_dos_1)
READ(5, *, err=100, end=100, iostat=ios) temp1, temp2, deltat
100 IF (ios /= 0) STOP 'reading temperature'
!
!  Output sector
!
IF (deltat <= 0.0_8) STOP 'Negative deltat'
ntemp=1+(temp2-temp1)/deltat
ALLOCATE(temp(ntemp))
ALLOCATE(f_ene(ntemp))
ALLOCATE(ene(ntemp))
ALLOCATE(ent(ntemp))
ALLOCATE(cv(ntemp))
CALL zero_point_energy(phdos_1, e0)
CALL integrated_dos(phdos_1, tot_states)
WRITE(6,'("# Zero point energy is:", f15.5, " Ry")') e0
WRITE(6,'("# Total number of states is:", f15.5, " Ry")') tot_states
DO itemp = 1, ntemp
   temp(itemp) = temp1 + (itemp-1) * deltat
   CALL free_energy(phdos_1, temp(itemp), f_ene(itemp))
   CALL vib_energy(phdos_1, temp(itemp), ene(itemp))
   CALL vib_entropy(phdos_1, temp(itemp), ent(itemp))
   CALL specific_heat_cv(phdos_1, temp(itemp), cv(itemp))
END DO

WRITE(6,'("# Temperature T in K, ")')
WRITE(6,'("# Energy and free energy in Ry/cell,")')
WRITE(6,'("# Entropy in Ry / (cell K)")')
WRITE(6,'("# Specific heat Cv in Ry / (cell K)")')
WRITE(6,'("# Multiply by 13.6058 to have energies in eV / cell etc.")')
WRITE(6,'("# Multiply by 13.6058 x 23060.35 = 313 754.5 to have energies in cal / mol")')
WRITE(6,'("# assuming that N_A cells contain 1 mole (N_A is the Avogadro")')
WRITE(6,'("# number). If N_A cells contain N moles (for instance in ")')
WRITE(6,'("# silicon N=2) divide by N to have energies in cal / mol etc. ")')
WRITE(6,'("# Multiply by 13.6058 x 96526.0 = 1 313 313 to have energies in J / mol")')

WRITE(6,'("#",5x,"   T  ", 7x, " energy ", 4x, "  free energy ",&
              4x, " entropy ", 7x, " Cv ")') 

DO itemp = 1, ntemp
   WRITE(6, '(5e15.6)') temp(itemp), e0+ene(itemp), e0+f_ene(itemp), &
                        ent(itemp), cv(itemp)

END DO

DEALLOCATE ( temp )
DEALLOCATE ( f_ene )
DEALLOCATE ( ene )
DEALLOCATE ( ent )
DEALLOCATE ( cv )

END PROGRAM print_thermo

