#!/bin/bash

. ../environment.sh

cd $PROG/STEP_2
if test ! -d $TMP_DIR ; then
   mkdir $TMP_DIR
fi

el1='Sn'
name=$el1

cat > $name.d <<EOF
$el1
$el1
 &control
    calculation = 'scf'
    restart_mode='from_scratch',
    prefix='$el1',
    tstress = .true.
    tprnfor = .true.
    pseudo_dir = '$PSEUDO_DIR',
    outdir='$TMP_DIR'
 /
 &system    
    ibrav = 2, 
    celldm(1) = 12.17, 
    nat = 2, 
    ntyp = 1,
    occupations = 'smearing',
    smearing='mp',
    degauss = 0.03,
    ecutwfc = 14.0, 
 /
 &electrons
    conv_thr =  1.0d-10
 /
ATOMIC_SPECIES
$el1  0.0    Sn.pz-nc.UPF
ATOMIC_POSITIONS
$el1  0.0000000   0.00000000   0.0  
$el1  0.2500000   0.25000000   0.25
K_POINTS AUTOMATIC
8 8 8 1 1 1 
EOF

$ECHO "  running the scf calculation for alpha Sn...\c"
$PW_COMMAND < $name.d$i >> $name.out$i
$ECHO " done"

cat > Sn_alpha.ph.in <<EOF
phonons of Sn 
 &inputph
  tr2_ph=1.0d-16,
  prefix='$el1',
  ldisp=.true.,
  nq1=4,
  nq2=4,
  nq3=4,
  outdir='$TMP_DIR',
  fildyn='$name.dyn',
 /
EOF

$ECHO "  running the phonon calculation for alpha Sn...\c"
$PH_COMMAND < Sn_alpha.ph.in > Sn_alpha.ph.out
$ECHO " done"

cat > q2r.in <<EOF
 &input
  fildyn='$name.dyn',  
  zasr='simple', 
  flfrc='$name.444.fc'
 /
EOF

$ECHO "  calculating interatomic force constants for alpha Sn...\c"
$Q2R_COMMAND < q2r.in > q2r.out
$ECHO " done"

cat > matdyn.in <<EOF
 &input
    asr='simple',  
    amass(1)=118.710, 
    flfrc='$name.444.fc', 
    flfrq='$name.freq'
    q_in_band_form=.true.,
 /
6
0.0 0.0 0.0 60
1.0 0.0 0.0 30
1.0 0.5 0.0 30
1.0 1.0 0.0 60
0.0 0.0 0.0 50
0.5 0.5 0.5 1
EOF

$ECHO "  calculating dynamical matrices for alpha Sn...\c"
$MATDYN_COMMAND < matdyn.in > matdyn.ph.out
$ECHO " done"

cat > phdos.in <<EOF
 &input
    asr='simple',  dos=.true., amass(1)=118.710,
    flfrc='$name.444.fc', fldos='Sn_alpha.phdos', 
    nk1=32,
    nk2=32,
    nk3=32
 /
EOF

$ECHO " calculating phonon DOS alpha Sn...\c"
$MATDYN_COMMAND < phdos.in > phdos.out
$ECHO " done"

cat > plotband.in <<EOF
Sn.freq
0 220
freq.plot
none
0.
1 0.
EOF

$ECHO " writing dispersions on file for alpha Sn...\c"
$PLOTBAND_COMMAND < plotband.in > plotband.out
$ECHO " done"

gnuplot plot_dispersion.gnu
