#!/bin/bash

. ../environment.sh

cd $PROG/STEP_5
if test ! -d $TMP_DIR ; then
   mkdir $TMP_DIR
fi

el1='Sn'
name='Sn_beta'

a=10.892
c_over_a=0.5437
a_over_c=$(echo 1.0 / $c_over_a | bc -l)
c_over_a_4=$(echo $c_over_a / 4.0 | bc -l)

cat > $name.d <<EOF
$el1
$el1
 &control
    calculation = 'scf'
    restart_mode='from_scratch',
    prefix='$el1',
    tstress = .true.
    tprnfor = .true.
    pseudo_dir = '$PSEUDO_DIR',
    outdir='$TMP_DIR'
 /
 &system    
    ibrav= 7
    celldm(1) = $a
    celldm(3) = $c_over_a
    nat = 2, 
    ntyp = 1,
    occupations = 'smearing',
    smearing='mp',
    degauss = 0.03,
    ecutwfc = 14.0, 
 /
 &electrons
    conv_thr =  1.0d-10
 /
ATOMIC_SPECIES
$el1  0.0    Sn.pz-nc.UPF
ATOMIC_POSITIONS
$el1  0.000000000   0.000000000  0.000000000
$el1  0.50   0.000000000   $c_over_a_4
K_POINTS AUTOMATIC
12 12 12 1 1 1 
EOF

$ECHO "  running the scf calculation for beta Sn...\c"
$PW_COMMAND < $name.d$i >> $name.out$i
$ECHO " done"

cat > Sn_beta.ph.in <<EOF
phonons of Sn 
 &inputph
  tr2_ph=1.0d-16,
  prefix='$el1',
  ldisp=.true.,
  nq1=6,
  nq2=6,
  nq3=6,
  outdir='$TMP_DIR',
  fildyn='$name.dyn',
 /
EOF

$ECHO "  running the phonon calculation for beta Sn...\c"
#$PH_COMMAND < Sn_beta.ph.in > Sn_beta.ph.out
cp reference/Sn_beta.dyn* .
$ECHO " done"

cat > q2r.in <<EOF
 &input
  fildyn='$name.dyn',  
  zasr='simple', 
  flfrc='$name.666.fc'
 /
EOF

$ECHO "  calculating interatomic force constants for beta Sn...\c"
$Q2R_COMMAND < q2r.in > q2r.out
$ECHO " done"

cat > matdyn.in <<EOF
 &input
    asr='simple',  
    amass(1)=118.710, 
    flfrc='$name.666.fc', 
    flfrq='$name.freq'
    q_in_band_form=.true.,
 /
5
0.0 0.0 0.0 100
0.0 0.0 $a_over_c 0
1.0 0.0 0.0 100
0.0 0.0 0.0 80
0.5 0.5 0.0 1
EOF

$ECHO "  calculating dynamical matrices for beta Sn...\c"
$MATDYN_COMMAND < matdyn.in > matdyn.ph.out
$ECHO " done"

cat > plotband.in <<EOF
Sn_beta.freq
0 150
freq.plot
none
0.
1 0.
EOF

$ECHO "  writing dispersions on file for beta Sn...\c"
$PLOTBAND_COMMAND < plotband.in > plotband.out
$ECHO " done"

gnuplot plot_dispersion.gnu

cat > phdos.in <<EOF
 &input
    asr='simple',  dos=.true., amass(1)=118.710,
    flfrc='$name.666.fc', fldos='Sn_beta.phdos', 
    nk1=24,
    nk2=24,
    nk3=24,
 /
EOF

$ECHO "  calculating phonon DOS beta Sn...\c"
$MATDYN_COMMAND < phdos.in > phdos.out
$ECHO " done"

