set encoding iso_8859_15
set terminal postscript enhanced solid color "Helvetica" 24
set output "thermo.ps"
#
set key off

set border lw 3

set size 1.0,0.7

set ytics 1000
set xtics 100
dim0=-3500
dim1=2500
set yrange [dim0:dim1]
#set xrange [275:325]
set arrow from 286,dim0 to 286,dim1 nohead lw 1 lt 2

set xlabel 'Temperature (K)'
set ylabel 'Energy (cal/mol)'
#
#  This is the energy difference between the two phases in cal/mol. We use 
#  the same value as in PRB 57, 10421 (1998). The final transition
#  temperature depends on this value. Since it is quite small 
#  the convergence of this number requires a careful check with cut-off, 
#  k-points and smearing. As an exercise calculate the fully converged value
#  and recalculate the transition temperature.
#
#diff=500
diff=516
#diff=594
#
#  This is the value of the vibrational energy or of the free energy at T=0 
#  for the alpha phase. We arbitrarily set the zero of energy to this
#  value. (In Ry per cell)
#
e0=0.337199E-02
#
#  Convert from Ry per cell to cal/mol. The factor
#  13.6058 convert from Ry to eV, and the factor 23060.538 convert from 
#  eV to cal/cell. Dividing by the number of atoms per cell we get 
#  the result in cal/mol.
#
ry_to_cal = 13.6058 * 23060.538
#
nat=2

plot "thermo_alpha.dat" u 1:(($2-e0)*ry_to_cal/nat) w l lw 3 ; 
replot "thermo_alpha.dat" u 1:(($3-e0)*ry_to_cal/nat) w l lw 3 ; 
replot "thermo_beta.dat" u 1:(($2-e0)*ry_to_cal/nat+diff) w l lw 3 ; 
replot "thermo_beta.dat" u 1:(($3-e0)*ry_to_cal/nat+diff) w l lw 3 ; 
